package com.dcsoft.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dcsoft.system.mapper.SysBackGroupMapper;
import com.dcsoft.system.domain.SysBackGroup;
import com.dcsoft.system.service.ISysBackGroupService;

/**
 * 背景配置Service业务层处理
 *
 * @author dcsoft
 * @date 2024-03-01
 */
@Service
public class SysBackGroupServiceImpl implements ISysBackGroupService
{
    @Autowired
    private SysBackGroupMapper sysBackGroupMapper;

    /**
     * 查询背景配置
     *
     * @param id 背景配置主键
     * @return 背景配置
     */
    @Override
    public SysBackGroup selectSysBackGroupById(Long id)
    {
        return sysBackGroupMapper.selectSysBackGroupById(id);
    }

    /**
     * 查询背景配置列表
     *
     * @param sysBackGroup 背景配置
     * @return 背景配置
     */
    @Override
    public List<SysBackGroup> selectSysBackGroupList(SysBackGroup sysBackGroup)
    {
        return sysBackGroupMapper.selectSysBackGroupList(sysBackGroup);
    }

    /**
     * 新增背景配置
     *
     * @param sysBackGroup 背景配置
     * @return 结果
     */
    @Override
    public int insertSysBackGroup(SysBackGroup sysBackGroup)
    {
        return sysBackGroupMapper.insertSysBackGroup(sysBackGroup);
    }

    /**
     * 修改背景配置
     *
     * @param sysBackGroup 背景配置
     * @return 结果
     */
    @Override
    public int updateSysBackGroup(SysBackGroup sysBackGroup)
    {
        return sysBackGroupMapper.updateSysBackGroup(sysBackGroup);
    }

    /**
     * 批量删除背景配置
     *
     * @param ids 需要删除的背景配置主键
     * @return 结果
     */
    @Override
    public int deleteSysBackGroupByIds(Long[] ids)
    {
        return sysBackGroupMapper.deleteSysBackGroupByIds(ids);
    }

    /**
     * 删除背景配置信息
     *
     * @param id 背景配置主键
     * @return 结果
     */
    @Override
    public int deleteSysBackGroupById(Long id)
    {
        return sysBackGroupMapper.deleteSysBackGroupById(id);
    }

    @Override
    public int deleteSysBackGroup() {
        return sysBackGroupMapper.deleteSysBackGroup();
    }


}
